@@ -3,7 +3,7 @@
  * CONFIG.C - Configuration input and verification routines for Icinga
  *
  * Copyright (c) 1999-2008 Ethan Galstad (egalstad@nagios.org)
- * Last Modified: 12-14-2008
+ * Copyright (c) 2009-2010 Icinga Development Team
  *
  * License:
  *
@@ -64,7 +64,9 @@ extern char     *illegal_output_chars;
 extern int      use_regexp_matches;
 extern int      use_true_regexp_matching;
 
-extern int	use_syslog;
+extern int      use_syslog;
+extern int      use_syslog_local_facility;
+extern int      syslog_local_facility;
 extern int      log_notifications;
 extern int      log_service_retries;
 extern int      log_host_retries;
@@ -213,6 +215,7 @@ extern char             *debug_file;
 extern int              debug_level;
 extern int              debug_verbosity;
 extern unsigned long    max_debug_file_size;
+extern int              event_profiling_enabled;
 
 
 
@@ -525,6 +528,28 @@ int read_main_config_file(char *main_config_file){
 			use_syslog=(atoi(value)>0)?TRUE:FALSE;
 			}
 
+		else if(!strcmp(variable,"use_syslog_local_facility")){
+
+			if(strlen(value)!=1||value[0]<'0'||value[0]>'1'){
+				asprintf(&error_message,"Illegal value for use_syslog_local_facility");
+				error=TRUE;
+				break;
+				}
+
+			use_syslog_local_facility=(atoi(value)>0)?TRUE:FALSE;
+			}
+
+		else if(!strcmp(variable,"syslog_local_facility")){
+
+			if(strlen(value)!=1||value[0]<'0'||value[0]>'7'){
+				asprintf(&error_message,"Illegal value for syslog_local_facility");
+				error=TRUE;
+				break;
+				}
+
+			syslog_local_facility=atoi(value);
+			}
+
 		else if(!strcmp(variable,"log_notifications")){
 
 			if(strlen(value)!=1||value[0]<'0'||value[0]>'1'){
@@ -1309,6 +1334,11 @@ int read_main_config_file(char *main_config_file){
 		else if(!strcmp(variable,"bare_update_check"))
 			bare_update_check=(atoi(value)>0)?TRUE:FALSE;
 
+               else if(!strcmp(variable,"event_profiling_enabled"))
+                       event_profiling_enabled=(atoi(value)>0)?TRUE:FALSE;
+
+
+
 		/*** AUTH_FILE VARIABLE USED BY EMBEDDED PERL INTERPRETER ***/
 		else if(!strcmp(variable,"auth_file")){
 
@@ -1347,6 +1377,8 @@ int read_main_config_file(char *main_config_file){
 			continue;
 		else if(strstr(input,"state_retention_file=")==input)
 			continue;
+                else if(strstr(input,"sync_retention_file=")==input)
+                        continue;
 		else if(strstr(input,"object_cache_file=")==input)
 			continue;
 		else if(strstr(input,"precached_object_file=")==input)
