@@ -3,7 +3,7 @@
  * SEHANDLERS.C - Service and host event and state handlers for Icinga
  *
  * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
- * Last Modified:   01-02-2009
+ * Copyright (c) 2009-2010 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -747,8 +747,14 @@ int handle_host_state(host *hst){
 			check_pending_flex_host_downtime(hst);
 
 		/* notify contacts about the recovery or problem if its a "hard" state */
-		if(hst->state_type==HARD_STATE)
+		if(hst->state_type==HARD_STATE){
+
+#ifdef USE_ST_BASED_ESCAL_RANGES
+			hst->current_down_notification_number=0;
+			hst->current_unreachable_notification_number=0;
+#endif
 			host_notification(hst,NOTIFICATION_NORMAL,NULL,NULL,NOTIFICATION_OPTION_NONE);
+		}
 
 		/* handle the host state change */
 		handle_host_event(hst);
