@@ -2,9 +2,8 @@
  *
  * CGIUTILS.C - Common utilities for Icinga CGIs
  * 
- * Copyright (c) 1999-2008 Ethan Galstad (egalstad@nagios.org)
- *
- * Last Modified: 05-05-2009
+ * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
+ * Copyright (c) 2009-2010 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -98,6 +97,7 @@ int             use_authentication=TRUE;
 int             interval_length=60;
 
 int             show_context_help=FALSE;
+int		show_all_services_host_is_authorized_for=TRUE;
 
 int             use_pending_states=TRUE;
 
@@ -130,9 +130,6 @@ extern servicestatus   *servicestatus_list;
 
 lifo            *lifo_list=NULL;
 
-char            *my_strtok_buffer=NULL;
-char            *original_my_strtok_buffer=NULL;
-
 char encoded_url_string[2][MAX_INPUT_BUFFER]; // 2 to be able use url_encode twice
 char *encoded_html_string=NULL;
 
@@ -144,8 +141,18 @@ extern char     *tzname[2];
 #endif
 #endif
 
+int check_daemon_running(void);
 
-
+/*
+ * These function stubs allow us to compile a lot of the
+ * source-files common to cgi's and daemon without adding
+ * a whole bunch of #ifdef's everywhere. Note that we can't
+ * have them as macros, since the goal is to compile the
+ * source-files once. A decent linker will make the call
+ * a no-op anyway, so it's not a big issue
+ */
+void logit(int data_type, int display, const char *fmt, ...) { return; }
+int log_debug_info(int leve, int verbosity, const char *fmt, ...) { return 0; }
 
 /**********************************************************
  ***************** CLEANUP FUNCTIONS **********************
@@ -203,9 +210,6 @@ void reset_cgi_vars(void){
 
 	ping_syntax=NULL;
 
-	my_strtok_buffer=NULL;
-	original_my_strtok_buffer=NULL;
-
 	return;
         }
 
@@ -305,6 +309,9 @@ int read_cgi_config_file(char *filename){
 		else if(!strcmp(var,"show_context_help"))
 			show_context_help=(atoi(val)>0)?TRUE:FALSE;
 
+		else if(!strcmp(var,"show_all_services_host_is_authorized_for"))
+			show_all_services_host_is_authorized_for=(atoi(val)>0)?TRUE:FALSE;
+
 		else if(!strcmp(var,"use_pending_states"))
 			use_pending_states=(atoi(val)>0)?TRUE:FALSE;
 
@@ -587,66 +594,6 @@ int read_all_status_data(char *config_file,int options){
         }
 
 
-
-/**********************************************************
- *************** CHAINED HASH FUNCTIONS *******************
- **********************************************************/
-
-
-/* dual hash function */
-int hashfunc(const char *name1,const char *name2,int hashslots){
-	unsigned int i,result;
-
-	result=0;
-
-	if(name1)
-		for(i=0;i<strlen(name1);i++)
-			result+=name1[i];
-
-	if(name2)
-		for(i=0;i<strlen(name2);i++)
-			result+=name2[i];
-
-	result=result%hashslots;
-
-	return result;
-        }
-
-
-/* dual hash data comparison */
-int compare_hashdata(const char *val1a, const char *val1b, const char *val2a, const char *val2b){
-	int result=0;
-
-	/* NOTE: If hash calculation changes, update the compare_strings() function! */
-
-	/* check first name */
-	if(val1a==NULL && val2a==NULL)
-		result=0;
-	else if(val1a==NULL)
-		result=1;
-	else if(val2a==NULL)
-		result=-1;
-	else
-		result=strcmp(val1a,val2a);
-
-	/* check second name if necessary */
-	if(result==0){
-		if(val1b==NULL && val2b==NULL)
-			result=0;
-		else if(val1b==NULL)
-			result=1;
-		else if(val2b==NULL)
-			result=-1;
-		else
-			result=strcmp(val1b,val2b);
-	        }
-
-	return result;
-        }
-
-
-
-
 /**********************************************************
  ******************* LIFO FUNCTIONS ***********************
  **********************************************************/
@@ -759,42 +706,6 @@ char *pop_lifo(void){
  **********************************************************/
 
 
-/* strip newline, carriage return, and tab characters from beginning and end of a string */
-void strip(char *buffer){
-	register int x;
-	register int y;
-	register int z;
-
-	if(buffer==NULL || buffer[0]=='\x0')
-		return;
-
-	/* strip end of string */
-	y=(int)strlen(buffer);
-	for(x=y-1;x>=0;x--){
-		if(buffer[x]==' ' || buffer[x]=='\n' || buffer[x]=='\r' || buffer[x]=='\t' || buffer[x]==13)
-			buffer[x]='\x0';
-		else
-			break;
-	        }
-
-	/* strip beginning of string (by shifting) */
-	y=(int)strlen(buffer);
-	for(x=0;x<y;x++){
-		if(buffer[x]==' ' || buffer[x]=='\n' || buffer[x]=='\r' || buffer[x]=='\t' || buffer[x]==13)
-			continue;
-		else
-			break;
-	        }
-	if(x>0){
-		for(z=x;z<y;z++)
-			buffer[z-x]=buffer[z];
-		buffer[y-x]='\x0';
-	        }
-
-	return;
-	}
-
-
 /* unescapes newlines in a string */
 char *unescape_newlines(char *rawbuf){
 	register int x,y;
@@ -964,77 +875,6 @@ void get_time_string(time_t *raw_time,char *buffer,int buffer_length,int type){
         }
 
 
-
-/* given a date/time in time_t format, produce a corresponding date/time string, including timezone */
-void get_datetime_string(time_t *raw_time,char *buffer,int buffer_length, int type){
-	time_t t;
-	struct tm *tm_ptr=NULL;
-	int hour=0;
-	int minute=0;
-	int second=0;
-	int month=0;
-	int day=0;
-	int year=0;
-	char *weekdays[7]={"Sun","Mon","Tue","Wed","Thu","Fri","Sat"};
-	char *months[12]={"Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sept","Oct","Nov","Dec"};
-
-#ifdef HAVE_TM_ZONE
-# define tzone tm_ptr->tm_zone
-#else
-# define tzone (tm_ptr->tm_isdst)?tzname[1]:tzname[0]
-#endif
-
-	if(raw_time==NULL)
-		time(&t);
-	else 
-		t=*raw_time;
-
-	tm_ptr=localtime(&t);
-
-	hour=tm_ptr->tm_hour;
-	minute=tm_ptr->tm_min;
-	second=tm_ptr->tm_sec;
-	month=tm_ptr->tm_mon+1;
-	day=tm_ptr->tm_mday;
-	year=tm_ptr->tm_year+1900;
-
-	/* ctime() style date/time */
-	if(type==LONG_DATE_TIME)
-		snprintf(buffer,buffer_length,"%s %s %d %02d:%02d:%02d %s %d",weekdays[tm_ptr->tm_wday],months[tm_ptr->tm_mon],day,hour,minute,second,tzone,year);
-
-	/* short date/time */
-	else if(type==SHORT_DATE_TIME){
-		if(date_format==DATE_FORMAT_EURO)
-			snprintf(buffer,buffer_length,"%02d-%02d-%04d %02d:%02d:%02d",day,month,year,hour,minute,second);
-		else if(date_format==DATE_FORMAT_ISO8601 || date_format==DATE_FORMAT_STRICT_ISO8601)
-			snprintf(buffer,buffer_length,"%04d-%02d-%02d%c%02d:%02d:%02d",year,month,day,(date_format==DATE_FORMAT_STRICT_ISO8601)?'T':' ',hour,minute,second);
-		else
-			snprintf(buffer,buffer_length,"%02d-%02d-%04d %02d:%02d:%02d",month,day,year,hour,minute,second);
-	        }
-
-	/* short date */
-	else if(type==SHORT_DATE){
-		if(date_format==DATE_FORMAT_EURO)
-			snprintf(buffer,buffer_length,"%02d-%02d-%04d",day,month,year);
-		else if(date_format==DATE_FORMAT_ISO8601 || date_format==DATE_FORMAT_STRICT_ISO8601)
-			snprintf(buffer,buffer_length,"%04d-%02d-%02d",year,month,day);
-		else
-			snprintf(buffer,buffer_length,"%02d-%02d-%04d",month,day,year);
-	        }
-
-	/* short time */
-	else
-		snprintf(buffer,buffer_length,"%02d:%02d:%02d",hour,minute,second);
-
-	buffer[buffer_length-1]='\x0';
-
-	/* don't mess up other functions that might want to call a variable 'tzone' */
-#undef tzone
-
-	return;
-        }
-
-
 /* get time string for an interval of time */
 void get_interval_time_string(double time_units,char *buffer,int buffer_length){
 	unsigned long total_seconds;
@@ -1055,315 +895,6 @@ void get_interval_time_string(double time_units,char *buffer,int buffer_length){
         }
 
 
-/* fix the problem with strtok() skipping empty options between tokens */	
-char *my_strtok(char *buffer,char *tokens){
-	char *token_position;
-	char *sequence_head;
-
-	if(buffer!=NULL){
-		if(original_my_strtok_buffer!=NULL)
-			free(original_my_strtok_buffer);
-		my_strtok_buffer=malloc(strlen(buffer)+1);
-		if(my_strtok_buffer==NULL)
-			return NULL;
-		original_my_strtok_buffer=my_strtok_buffer;
-		strcpy(my_strtok_buffer,buffer);
-	        }
-	
-	sequence_head=my_strtok_buffer;
-
-	if(sequence_head[0]=='\x0')
-		return NULL;
-	
-	token_position=index(my_strtok_buffer,tokens[0]);
-
-	if(token_position==NULL){
-		my_strtok_buffer=index(my_strtok_buffer,'\x0');
-		return sequence_head;
-	        }
-
-	token_position[0]='\x0';
-	my_strtok_buffer=token_position+1;
-
-	return sequence_head;
-
-        }
-
-
-/* fixes compiler problems under Solaris, since strsep() isn't included */
-/* this code is taken from the glibc source */
-char *my_strsep (char **stringp, const char *delim){
-	char *begin, *end;
-
-	begin = *stringp;
-	if (begin == NULL)
-		return NULL;
-
-	/* A frequent case is when the delimiter string contains only one
-	   character.  Here we don't need to call the expensive `strpbrk'
-	   function and instead work using `strchr'.  */
-	if(delim[0]=='\0' || delim[1]=='\0'){
-		char ch = delim[0];
-
-		if(ch=='\0' || begin[0]=='\0')
-			end=NULL;
-		else{
-			if(*begin==ch)
-				end=begin;
-			else
-				end=strchr(begin+1,ch);
-			}
-		}
-
-	else
-		/* Find the end of the token.  */
-		end = strpbrk (begin, delim);
-
-	if(end){
-
-		/* Terminate the token and set *STRINGP past NUL character.  */
-		*end++='\0';
-		*stringp=end;
-		}
-	else
-		/* No more delimiters; this is the last token.  */
-		*stringp=NULL;
-
-	return begin;
-	}
-
-
-#ifdef REMOVED_10182007
-/* my wrapper for free() */
-int my_free(void **ptr){
-
-	if(ptr==NULL)
-		return ERROR;
-
-	/* I hate calling free() and then resetting the pointer to NULL, so lets do it together */
-	if(*ptr){
-		free(*ptr);
-		*ptr=NULL;
-	        }
-
-	return OK;
-        }
-#endif
-
-
-/* open a file read-only via mmap() */
-mmapfile *mmap_fopen(char *filename){
-	mmapfile *new_mmapfile;
-	int fd;
-	void *mmap_buf;
-	struct stat statbuf;
-	int mode=O_RDONLY;
-
-	/* allocate memory */
-	if((new_mmapfile=(mmapfile *)malloc(sizeof(mmapfile)))==NULL)
-		return NULL;
-
-	/* open the file */
-	if((fd=open(filename,mode))==-1)
-		return NULL;
-
-	/* get file info */
-	if((fstat(fd,&statbuf))==-1){
-		close(fd);
-		free(new_mmapfile);
-		return NULL;
-	        }
-
-	/* mmap() the file */
-	if((mmap_buf=(void *)mmap(0,statbuf.st_size,PROT_READ,MAP_PRIVATE,fd,0))==MAP_FAILED){
-		close(fd);
-		free(new_mmapfile);
-		return NULL;
-	        }
-
-	/* populate struct info for later use */
-	new_mmapfile->path=strdup(filename);
-	new_mmapfile->fd=fd;
-	new_mmapfile->file_size=(unsigned long)(statbuf.st_size);
-	new_mmapfile->current_position=0L;
-	new_mmapfile->current_line=0L;
-	new_mmapfile->mmap_buf=mmap_buf;
-
-	return new_mmapfile;
-        }
-
-
-
-/* close a file originally opened via mmap() */
-int mmap_fclose(mmapfile *temp_mmapfile){
-
-	if(temp_mmapfile==NULL)
-		return ERROR;
-
-	/* un-mmap() the file */
-	munmap(temp_mmapfile->mmap_buf,temp_mmapfile->file_size);
-
-	/* close the file */
-	close(temp_mmapfile->fd);
-
-	/* free memory */
-	free(temp_mmapfile);
-	
-	return OK;
-        }
-
-
-
-/* gets one line of input from an mmap()'ed file */
-char *mmap_fgets(mmapfile *temp_mmapfile){
-	char *buf=NULL;
-	unsigned long x=0L;
-	int len=0;
-
-	if(temp_mmapfile==NULL)
-		return NULL;
-
-	/* size of file is 0 bytes */
-	if(temp_mmapfile->file_size==0L)
-		return NULL;
-
-	/* we've reached the end of the file */
-	if(temp_mmapfile->current_position>=temp_mmapfile->file_size)
-		return NULL;
-
-	/* find the end of the string (or buffer) */
-	for(x=temp_mmapfile->current_position;x<temp_mmapfile->file_size;x++){
-		if(*((char *)(temp_mmapfile->mmap_buf)+x)=='\n'){
-			x++;
-			break;
-			}
-	        }
-
-	/* calculate length of line we just read */
-	len=(int)(x-temp_mmapfile->current_position);
-
-	/* allocate memory for the new line */
-	if((buf=(char *)malloc(len+1))==NULL)
-		return NULL;
-
-	/* copy string to newly allocated memory and terminate the string */
-	memcpy(buf,((char *)(temp_mmapfile->mmap_buf)+temp_mmapfile->current_position),len);
-	buf[len]='\x0';
-
-	/* update the current position */
-	temp_mmapfile->current_position=x;
-
-	/* increment the current line */
-	temp_mmapfile->current_line++;
-
-	return buf;
-        }
-
-
-
-/* gets one line of input from an mmap()'ed file (may be contained on more than one line in the source file) */
-char *mmap_fgets_multiline(mmapfile *temp_mmapfile){
-	char *buf=NULL;
-	char *tempbuf=NULL;
-	char *stripped=NULL;
-	int len=0;
-	int len2=0;
-	int end=0;
-
-	if(temp_mmapfile==NULL)
-		return NULL;
-
-	while(1){
-
-		my_free(tempbuf);
-
-		if((tempbuf=mmap_fgets(temp_mmapfile))==NULL)
-			break;
-
-		if(buf==NULL){
-			len=strlen(tempbuf);
-			if((buf=(char *)malloc(len+1))==NULL)
-				break;
-			memcpy(buf,tempbuf,len);
-			buf[len]='\x0';
-		        }
-		else{
-			/* strip leading white space from continuation lines */
-			stripped=tempbuf;
-			while(*stripped==' ' || *stripped=='\t')
-				stripped++;
-			len=strlen(stripped);
-			len2=strlen(buf);
-			if((buf=(char *)realloc(buf,len+len2+1))==NULL)
-				break;
-			strcat(buf,stripped);
-			len+=len2;
-			buf[len]='\x0';
-		        }
-
-		if(len==0)
-			break;
-
-		/* handle Windows/DOS CR/LF */
-		if(len>=2 && buf[len-2]=='\r')
-			end=len-3;
-		/* normal Unix LF */
-		else if(len>=1 && buf[len-1]=='\n')
-			end=len-2;
-		else
-			end=len-1;
-
-		/* two backslashes found, so unescape first backslash first and break */
-		if(end>=1 && buf[end-1]=='\\' && buf[end]=='\\'){
-			buf[end]='\n';
-			buf[end+1]='\x0';
-			break;
-			}
-
-		/* one backslash found, so we should continue reading the next line */
-		else if(end>0 && buf[end]=='\\')
-			buf[end]='\x0';
-
-		/* else no continuation marker was found, so break */
-		else
-			break;
-	        }
-
-	my_free(tempbuf);
-
-	return buf;
-        }
-
-
-
-/* get days, hours, minutes, and seconds from a raw time_t format or total seconds */
-void get_time_breakdown(unsigned long raw_time,int *days,int *hours,int *minutes,int *seconds){
-	unsigned long temp_time;
-	int temp_days;
-	int temp_hours;
-	int temp_minutes;
-	int temp_seconds;
-
-	temp_time=raw_time;
-
-	temp_days=temp_time/86400;
-	temp_time-=(temp_days * 86400);
-	temp_hours=temp_time/3600;
-	temp_time-=(temp_hours * 3600);
-	temp_minutes=temp_time/60;
-	temp_time-=(temp_minutes * 60);
-	temp_seconds=(int)temp_time;
-
-	*days=temp_days;
-	*hours=temp_hours;
-	*minutes=temp_minutes;
-	*seconds=temp_seconds;
-
-	return;
-	}
-
-
-
 /* encodes a string in proper URL format */
 char * url_encode(char *input){
 	int len,output_len;
@@ -1601,6 +1132,18 @@ void get_log_archive_to_use(int archive,char *buffer,int buffer_length){
 	if((fd = fopen(buffer, "r")) == NULL){
 		snprintf(buffer,buffer_length,"%snagios-%02d-%02d-%d-%02d.log",log_archive_path,t->tm_mon+1,t->tm_mday,t->tm_year+1900,t->tm_hour);
 		buffer[buffer_length-1]='\x0';
+
+		/* 06-02-2010 Michael Friedrich
+		   Yeah, and if no log has been written, nagios- will fail with the wrong error message
+		   leading the user to the assumption that the logfile is not even created - if the logfile
+		   was not rotated by the core after this date */
+		if((fd = fopen(buffer, "r")) == NULL){
+			snprintf(buffer,buffer_length,"%sicinga-%02d-%02d-%d-%02d.log",log_archive_path, t->tm_mon+1, t->tm_mday, t->tm_year+1900, t->tm_hour);
+			buffer[buffer_length-1]='\x0';
+		}
+		else {
+			fclose(fd);
+		}
 	}
 	else {
 		fclose(fd);
@@ -2291,9 +1834,7 @@ int check_daemon_running(void) {
 	char *proc_file=NULL;
 	char *input = NULL;
 	char *val = NULL;
-	char *daemon_name = NULL;
-	struct stat statbuf;
-	int pid, testpid, found;
+	int pid, testpid;
 	char input_buffer[CHARLEN];
 	mmapfile *fk;
 	FILE *fp;
@@ -2303,34 +1844,12 @@ int check_daemon_running(void) {
                 return ERROR;
         }
 
-	if((fk=mmap_fopen(lock_file))==NULL) {
-
-		/* no lock file found try program name instead */
-                asprintf(&daemon_name,"%s",PROGRAM_NAME_LC);
-
-                if(asprintf(&proc_file,"/bin/ps -o pid -C %s",daemon_name)==-1) {
-                        free(proc_file);
-                        return ERROR;
-                }
-
-                if((fp=popen(proc_file, "r"))==NULL) {
-                        free(proc_file);
-                        return ERROR;
-                }
-
-                fgets(input_buffer,CHARLEN-1,fp);
-                fgets(input_buffer,CHARLEN-1,fp);
-
-                /* check if entry found */
-                if (sscanf(input_buffer,"%d",&testpid)!=1) {
-                        free(proc_file);
-                        return ERROR;
-                } else {
-			/* daemon is running */
-			free(proc_file);
-			return OK;
-		}
-	}
+	/* since 'ps -C process' is no working on macosx, we'll drop that again
+	   the init script of the core is now safe - if the core segfaulted after
+	   after starting up, the lockfile is removed. so if there is no lockfile
+	   no daemon is assumed running  */
+	if((fk=mmap_fopen(lock_file))==NULL) 
+		return ERROR;
         
 	if((input=mmap_fgets(fk))==NULL) {
 		mmap_fclose(fk);
