@@ -1,10 +1,9 @@
 /************************************************************************
  *
  * Icinga Common Header File
- * Written By: Ethan Galstad (egalstad@nagios.org)
- * Modified By: Icinga Development Team (http://www.icinga.org)
  *
- * Last Modified: 05-11-2009
+ * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
+ * Copyright (c) 2009-2010 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -22,12 +21,13 @@
  * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
  ************************************************************************/
 
+#include "shared.h"
 
 #define PROGRAM_NAME "Icinga"
 #define PROGRAM_NAME_UC "ICINGA"
 #define PROGRAM_NAME_LC "icinga"
-#define PROGRAM_VERSION "1.0.1"
-#define PROGRAM_MODIFICATION_DATE "03-03-2010"
+#define PROGRAM_VERSION "1.0.2"
+#define PROGRAM_MODIFICATION_DATE "06-30-2010"
 
 /*#define DEBUG_CHECK_IPC 1 */
 /*#define DEBUG_CHECK_IPC2 1*/
@@ -304,6 +304,8 @@
 #define CMD_CHANGE_CONTACT_MODHATTR                     168
 #define CMD_CHANGE_CONTACT_MODSATTR                     169
 
+#define CMD_SYNC_STATE_INFORMATION                      170
+
 /* custom command introduced in Nagios 3.x */
 #define CMD_CUSTOM_COMMAND                              999
 
