@@ -2,8 +2,8 @@
  *
  * OBJECTS.H - Header file for object addition/search functions
  *
- * Copyright (c) 1999-2007 Ethan Galstad (egalstad@nagios.org)
- * Last Modified: 11-10-2007
+ * Copyright (c) 1999-2009 Ethan Galstad (egalstad@nagios.org)
+ * Copyright (c) 2009-2010 Icinga Development Team (http://www.icinga.org)
  *
  * License:
  *
@@ -66,6 +66,12 @@
 #define HOSTESCALATION_SKIPLIST                10
 #define SERVICEESCALATION_SKIPLIST             11
 
+/****************** DEFINITIONS *******************/
+/*#define VOLATILE_FALSE 0 - uses FALSE*/
+/*#define VOLATILE_TRUE  1 - uses TRUE */
+#define VOLATILE_WITH_RENOTIFICATION_INTERVAL 2
+
+
 /******** escalation condition connectors ******/
 #define EC_CONNECTOR_NO                   0
 #define EC_CONNECTOR_OR                   1
@@ -365,6 +371,10 @@ struct host_struct{
 	int     notified_on_down;
 	int     notified_on_unreachable;
 	int     current_notification_number;
+#ifdef USE_ST_BASED_ESCAL_RANGES
+	int     current_down_notification_number;
+	int     current_unreachable_notification_number;
+#endif
 	int     no_more_notifications;
 	unsigned long current_notification_id;
 	int     check_flapping_recovery_notification;
@@ -471,7 +481,7 @@ struct service_struct{
 	char	*plugin_output;
 	char    *long_plugin_output;
 	char    *perf_data;
-        int     state_type;
+	int     state_type;
 	time_t	next_check;
 	int     should_be_scheduled;
 	time_t	last_check;
@@ -496,7 +506,12 @@ struct service_struct{
 	int     notified_on_warning;
 	int     notified_on_critical;
 	int     current_notification_number;
-        unsigned long current_notification_id;
+#ifdef USE_ST_BASED_ESCAL_RANGES
+	int     current_warning_notification_number;
+	int     current_critical_notification_number;
+	int     current_unknown_notification_number;
+#endif
+	unsigned long current_notification_id;
 	double  latency;
 	double  execution_time;
 	int     is_executing;
@@ -558,6 +573,14 @@ typedef struct serviceescalation_struct{
 	char    *description;
 	int     first_notification;
 	int     last_notification;
+#ifdef USE_ST_BASED_ESCAL_RANGES
+	int     first_warning_notification;
+	int     last_warning_notification;
+	int     first_critical_notification;
+	int     last_critical_notification;
+	int     first_unknown_notification;
+	int     last_unknown_notification;
+#endif
 	double  notification_interval;
 	char    *escalation_period;
 	int     escalate_on_recovery;
@@ -608,6 +631,12 @@ typedef struct hostescalation_struct{
 	char    *host_name;
 	int     first_notification;
 	int     last_notification;
+#ifdef USE_ST_BASED_ESCAL_RANGES
+	int     first_down_notification;
+	int     last_down_notification;
+	int     first_unreachable_notification;
+	int     last_unreachable_notification;
+#endif
 	double  notification_interval;
 	char    *escalation_period;
 	int     escalate_on_recovery;
@@ -694,13 +723,21 @@ command *add_command(char *,char *);									/* adds a command definition */
 service *add_service(char *,char *,char *,char *,int,int,int,int,double,double,double,double,char *,int,int,int,int,int,int,int,int,char *,int,char *,int,int,double,double,int,int,int,int,int,int,int,int,int,int,char *,int,int,char *,char *,char *,char *,char *,int,int,int);	/* adds a service definition */
 contactgroupsmember *add_contactgroup_to_service(service *,char *);					/* adds a contact group to a service definition */
 contactsmember *add_contact_to_service(service *,char *);                                               /* adds a contact to a host definition */
+#ifndef USE_ST_BASED_ESCAL_RANGES
 serviceescalation *add_serviceescalation(char *,char *,int,int,double,char *,int,int,int,int);          /* adds a service escalation definition */
+#else
+serviceescalation *add_serviceescalation(char *,char *,int,int,int,int,int,int,int,int,double,char *,int,int,int,int);  /* adds a service escalation definition */
+#endif
 contactgroupsmember *add_contactgroup_to_serviceescalation(serviceescalation *,char *);                 /* adds a contact group to a service escalation definition */
 contactsmember *add_contact_to_serviceescalation(serviceescalation *,char *);                           /* adds a contact to a service escalation definition */
 customvariablesmember *add_custom_variable_to_service(service *,char *,char *);                         /* adds a custom variable to a service definition */
 servicedependency *add_service_dependency(char *,char *,char *,char *,int,int,int,int,int,int,int,char *);     /* adds a service dependency definition */
 hostdependency *add_host_dependency(char *,char *,int,int,int,int,int,int,char *);                             /* adds a host dependency definition */
+#ifndef USE_ST_BASED_ESCAL_RANGES
 hostescalation *add_hostescalation(char *,int,int,double,char *,int,int,int);                           /* adds a host escalation definition */
+#else 
+hostescalation *add_hostescalation(char *,int,int,int,int,int,int,double,char *,int,int,int);                           /* adds a host escalation definition */
+#endif
 contactsmember *add_contact_to_hostescalation(hostescalation *,char *);                                 /* adds a contact to a host escalation definition */
 contactgroupsmember *add_contactgroup_to_hostescalation(hostescalation *,char *);                       /* adds a contact group to a host escalation definition */
 
@@ -735,10 +772,6 @@ int get_service_count(void);
 
 
 
-/**** Object Hash Functions ****/
-int add_servicedependency_to_hashlist(servicedependency *);
-
-
 /**** Object Search Functions ****/
 timeperiod * find_timeperiod(char *);						                /* finds a timeperiod object */
 host * find_host(char *);									/* finds a host object */
@@ -765,6 +798,9 @@ int add_object_to_objectlist(objectlist **,void *);
 int free_objectlist(objectlist **);
 #endif
 
+/**** Object Hash Functions ****/
+int add_servicedependency_to_hashlist(servicedependency *);
+
 
 /**** Object Query Functions ****/
 int is_host_immediate_child_of_host(host *,host *);	                /* checks if a host is an immediate child of another host */	
@@ -773,9 +809,9 @@ int is_host_immediate_parent_of_host(host *,host *);	                /* checks i
 int is_host_member_of_hostgroup(hostgroup *,host *);		        /* tests whether or not a host is a member of a specific hostgroup */
 int is_host_member_of_servicegroup(servicegroup *,host *);	        /* tests whether or not a service is a member of a specific servicegroup */
 int is_service_member_of_servicegroup(servicegroup *,service *);	/* tests whether or not a service is a member of a specific servicegroup */
-int is_contact_member_of_contactgroup(contactgroup *, contact *);	/* tests whether or not a contact is a member of a specific contact group */
-int is_contact_for_hostgroup(hostgroup *,contact *);	                /* tests whether or not a contact is a member of a specific hostgroup */
-int is_contact_for_servicegroup(servicegroup *,contact *);	        /* tests whether or not a contact is a member of a specific servicegroup */
+int is_contact_member_of_contactgroup(contactgroup *, contact *);      	/* tests whether or not a contact is a member of a specific contact group */
+int is_contact_for_hostgroup(hostgroup *,contact *);                   	/* tests whether or not a contact is a member of a specific hostgroup */
+int is_contact_for_servicegroup(servicegroup *,contact *);             	/* tests whether or not a contact is a member of a specific servicegroup */
 int is_contact_for_host(host *,contact *);			        /* tests whether or not a contact is a contact member for a specific host */
 int is_escalated_contact_for_host(host *,contact *);                    /* checks whether or not a contact is an escalated contact for a specific host */
 int is_contact_for_service(service *,contact *);		        /* tests whether or not a contact is a contact member for a specific service */
