@@ -26,6 +26,16 @@ class IcingaApiSearchIdoPgsql
 	);
 
 	public $queryMap = array (
+		self::TARGET_INSTANCE =>
+			'select
+				${FIELDS}
+			from ${TABLE_PREFIX}instances i
+			where 1
+			${FILTER}
+			${GROUPBY}
+			${ORDERBY}
+			${LIMIT}',
+
 		self::TARGET_HOST =>
 			'select
 				distinct ${FIELDS}
@@ -236,6 +246,12 @@ class IcingaApiSearchIdoPgsql
 				${TABLE_PREFIX}statehistory sh
 			${if_table:oh:inner join ${TABLE_PREFIX}objects oh on oh.object_id = sh.object_id and oh.objecttype_id = 1}
 			${if_table:h,oh:inner join ${TABLE_PREFIX}hosts h on h.host_object_id = oh.object_id}
+			${if_table:i,h:inner join ${TABLE_PREFIX}instances i on i.instance_id = h.instance_id}
+			${if_table:hcg,h:inner join ${TABLE_PREFIX}host_contactgroups hcg on hcg.host_id = h.host_id}
+			${if_table:cg,h:inner join ${TABLE_PREFIX}contactgroups cg on cg.contactgroup_object_id = hcg.contactgroup_object_id}
+			${if_table:ocg,hcg,h:inner join ${TABLE_PREFIX}objects ocg on ocg.object_id = hcg.contactgroup_object_id and ocg.objecttype_id = 11}
+			${if_table:cgm,cg,hcg,h:inner join ${TABLE_PREFIX}contactgroup_members cgm on cgm.contactgroup_id = cg.contactgroup_id}
+			${if_table:oc,cgm,cg,hcg,h:inner join ${TABLE_PREFIX}objects oc on oc.object_id = cgm.contact_object_id}
 			${if_table:hgm,oh:inner join ${TABLE_PREFIX}hostgroup_members hgm on hgm.host_object_id = oh.object_id}
 			${if_table:hg,hgm,oh:inner join ${TABLE_PREFIX}hostgroups hg on hg.hostgroup_id = hgm.hostgroup_id}
 			${if_table:ohg,hg,hgm,oh:inner join ${TABLE_PREFIX}objects ohg on ohg.object_id = hg.hostgroup_object_id}
@@ -252,8 +268,13 @@ class IcingaApiSearchIdoPgsql
 				${TABLE_PREFIX}statehistory sh
 			${if_table:os:inner join ${TABLE_PREFIX}objects os on os.object_id = sh.object_id and os.objecttype_id = 2}
 			${if_table:s,os:inner join ${TABLE_PREFIX}services s on s.service_object_id = os.object_id}
+			${if_table:i,s:inner join ${TABLE_PREFIX}instances i on i.instance_id = s.instance_id}
 			${if_table:oh,s,os:inner join ${TABLE_PREFIX}objects oh on oh.object_id = s.host_object_id}
 			${if_table:h,oh,s,os:inner join ${TABLE_PREFIX}hosts h on h.host_object_id = oh.object_id}
+			${if_table:scg,s:inner join ${TABLE_PREFIX}service_contactgroups scg on scg.service_id = s.service_id}
+			${if_table:cg,scg,s:inner join ${TABLE_PREFIX}contactgroups cg on cg.contactgroup_object_id = scg.contactgroup_object_id}
+			${if_table:cgm,cg,scg,s:inner join ${TABLE_PREFIX}contactgroup_members cgm on cgm.contactgroup_id = cg.contactgroup_id}
+			${if_table:oc,cgm,cg,scg,s:inner join ${TABLE_PREFIX}objects oc on oc.object_id = cgm.contact_object_id}
 			${if_table:hgm,oh,s,os:inner join ${TABLE_PREFIX}hostgroup_members hgm on hgm.host_object_id = oh.object_id}
 			${if_table:hg,hgm,oh,s,os:inner join ${TABLE_PREFIX}hostgroups hg on hg.hostgroup_id = hgm.hostgroup_id}
 			${if_table:ohg,hg,hgm,oh,s,os:inner join ${TABLE_PREFIX}objects ohg on ohg.object_id = hg.hostgroup_object_id}
@@ -330,6 +351,11 @@ class IcingaApiSearchIdoPgsql
 		'PROGRAM_DATE' => array('pe', 'program_date'),
 		'PROGRAM_VERSION' => array('pe', 'program_version'),
 
+		// Instance things
+		'INSTANCE_ID' => array('i', 'instance_id'),
+		'INSTANCE_NAME' => array('i', 'instance_name'),
+		'INSTANCE_DESCRIPTION' => array('i', 'instance_description'),
+
 		// Hostgroup data
 		'HOSTGROUP_ID' => array('hg', 'hostgroup_id'),
 		'HOSTGROUP_OBJECT_ID' => array('ohg', 'object_id'),
